#
# spec file for package unionfs-fuse
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           unionfs-fuse
Version:        3.6
Release:        1.1
Summary:        Userspace Unionfs File System
License:        BSD-3-Clause
URL:            https://github.com/rpodgorny/unionfs-fuse
Source:         https://github.com/rpodgorny/unionfs-fuse/archive/v%{version}.tar.gz
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fuse3)
Requires:       fuse3
%if 0%{?suse_version} >= 1600
BuildRequires:  pkgconfig(libattr)
%else
BuildRequires:  libattr-devel
%endif

%description
unionfs-fuse overlays several directory into one single mount point

It  first  tries to access the file on the top branch and if the file
does not exist there, it continues on lower level branches. If the user
tries to modify a file on a lower level read-only branch the file is
copied to to a higher level read-write branch if the copy-on-write
(cow) mode was enabled.

%prep
%autosetup -p1

%build
%cmake -DWITH_XATTR=1
%cmake_build

%install
%cmake_install

%check
%ctest

%files
%license LICENSE
%doc CREDITS NEWS
%{_mandir}/man8/unionfs.8%{?ext_man}
%{_bindir}/unionfs
%{_bindir}/unionfsctl
%{_sbindir}/mount.unionfs

%changelog
* Fri Apr 25 2025 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.6:
  * fix long standing bug with directory renames in cow mode
  * disable logging to file since it had some unresolved locking
    issues
  * add support for direct_io
  * various nfs fixes and race conditions fixes
  * fuse3 support (boo#1242079)
  * add branch-preserving logic
- upstream cmake 4 compatibility
* Sat Mar 22 2025 Shawn Dunn <sfalken@opensuse.org>
- Add -DCMAKE_POLICY_VERSION_MINIMUM=3.5 to fix FTBFS with cmake4
- Add %%check section
- Remove Group: Declarations, no longer used
* Wed Aug  7 2024 ming li <mli@suse.com>
- update to 2.2:
  * fixed timestamp precision lost on cow copy
* Sun May  9 2021 Dirk Müller <dmueller@suse.com>
- update to 2.1:
  - fixed Finder fails on MacOS
  - Implement access() for "cow,relaxed_permissions" use case
  - fixed NEWS file ;-)
  - reverted meta directory name back to .unionfs (from .unionfs-fuse)
    this was never meant to be changed and slipped in in 1.0 release
  - fixes and speed improvements
* Mon Jul 11 2016 coolo@suse.com
- fix build by adding -fPIC
- clean up the spec file now that 13.1 is EOL
- add libattr as buildrequire
* Tue Apr  7 2015 p.drouand@gmail.com
- Update to version 1.0
  * renamed binary to unionfs-fuse
  * add uniofs-fuse-ctl utility to control unionfs-fuse over ioctl
  * better apple support
  * dropped stats
  * better test suite
- Update project and download Urls
- Use %%cmake macro with openSUSE >= 13.1
- Remove xz require; not needed anymore
* Mon Feb 11 2013 coolo@suse.com
- update to 0.26
  - use BUILD_PATH instead of snprintf, which will
  return -ENAMETOOLONG if the path is too long instead of simply
  using a wrong path
  - new options "-o relaxed_permissions" and "-o hide_meta_dir"
  - included the debian directory
  - Properly check on rmdir() if sub-branches are also empty
  - Always compile with debug code, but only enable debugging on request
  - New option -o debug_file
  - Lots of bugs fixed in BUILD_PATH()
  - Improved search of white-out files
  - Properly fix Debian Bug#509516.
  - More debug output.
  - Add syslog support without the risk of possible dead locks
  - Use fuse big-writes (and reads) if available
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Wed Feb 29 2012 tabraham@novell.com
- update to 0.25
  * Alternate way to specify branches
  * Minor fixes
- update to 0.24
  * Support for liveCDs / live USB sticks (-o chroot)
  * Build-in support to change the maximum number of open files
  * Added recursive directory COW.
* Tue Mar 24 2009 coolo@suse.de
- updated to official 0.23 snapshot
* Mon Mar  2 2009 coolo@suse.de
- initial package
